pub enum ChannelGraphError {
PublicKeyNodeNotFound(OffchainPublicKey),
}Expand description
Errors that can occur when manipulating the channel graph.
Variants
PublicKeyNodeNotFound(OffchainPublicKey)
Node identified by its public key not found in the graph.